import { H as HighlighterGeneric, B as BuiltinLanguage, a as BuiltinTheme, C as CodeToHastOptions, R as Root, b as RequireKeys, c as CodeToThemedTokensOptions, T as ThemedToken, d as CodeToTokensWithThemesOptions } from './types/langs.mjs';
export { A as AnsiLanguage, f as Awaitable, o as BundledHighlighterOptions, u as CodeOptionsMeta, s as CodeOptionsMultipleThemes, r as CodeOptionsSingleTheme, t as CodeOptionsThemes, q as CodeToHastOptionsCommon, F as FontStyle, n as HighlighterCoreOptions, D as HtmlRendererOptions, z as HtmlRendererOptionsCommon, e as IGrammar, I as IRawGrammar, L as LanguageInput, p as LanguageRegistration, h as MaybeArray, M as MaybeGetter, g as MaybeModule, P as PlainTextLanguage, k as ResolveBundleKey, m as ShikiContext, y as ShikijiTransformer, x as ShikijiTransformerContext, S as SpecialLanguage, j as StringLiteralUnion, i as ThemeInput, w as ThemeRegistration, v as ThemeRegistrationRaw, G as ThemedTokenExplanation, E as ThemedTokenScopeExplanation, O as bundledLanguages, N as bundledLanguagesAlias, K as bundledLanguagesBase, J as bundledThemes, l as loadWasm } from './types/langs.mjs';
import { GetHighlighterFactory } from './core.mjs';
export { HighlighterCore, addClassToHast, createSingletonShorthands, createdBundledHighlighter, getHighlighterCore, getShikiContext, isPlaintext, isSpecialLang, toArray, toShikiTheme } from './core.mjs';
export { getWasmInlined } from './wasm.mjs';

type Highlighter = HighlighterGeneric<BuiltinLanguage, BuiltinTheme>;
declare const getHighlighter: GetHighlighterFactory<"shellscript" | "bat" | "berry" | "csharp" | "cpp" | "cadence" | "clojure" | "vb" | "shellsession" | "cypher" | "docker" | "erlang" | "fsharp" | "jssm" | "glimmer-js" | "graphql" | "glimmer-ts" | "handlebars" | "haskell" | "pug" | "javascript" | "kusto" | "kotlin" | "make" | "markdown" | "narrat" | "nextflow" | "objective-c" | "raku" | "ini" | "powershell" | "python" | "codeql" | "ruby" | "rust" | "shaderlab" | "splunk" | "stylus" | "typescript" | "viml" | "vyper" | "yaml" | "wenyan" | "bash" | "batch" | "be" | "c#" | "c++" | "cdc" | "clj" | "cmd" | "console" | "cql" | "cs" | "dockerfile" | "erl" | "f#" | "fs" | "fsl" | "gjs" | "gql" | "gts" | "hbs" | "hs" | "jade" | "js" | "kql" | "kt" | "kts" | "makefile" | "md" | "nar" | "nf" | "objc" | "perl6" | "properties" | "ps" | "ps1" | "py" | "ql" | "rb" | "rs" | "sh" | "shader" | "shell" | "spl" | "styl" | "ts" | "vim" | "vimscript" | "vy" | "yml" | "zsh" | "文言" | "abap" | "actionscript-3" | "ada" | "apache" | "apex" | "apl" | "applescript" | "ara" | "asm" | "astro" | "awk" | "ballerina" | "beancount" | "bibtex" | "bicep" | "blade" | "c" | "clarity" | "cmake" | "cobol" | "coffee" | "crystal" | "css" | "cue" | "d" | "dart" | "dax" | "diff" | "dream-maker" | "elixir" | "elm" | "erb" | "fish" | "gdresource" | "gdscript" | "gdshader" | "gherkin" | "git-commit" | "git-rebase" | "glsl" | "gnuplot" | "go" | "groovy" | "hack" | "haml" | "hcl" | "hjson" | "hlsl" | "html" | "http" | "imba" | "java" | "jinja-html" | "jison" | "json" | "json5" | "jsonc" | "jsonl" | "jsonnet" | "jsx" | "julia" | "latex" | "less" | "liquid" | "lisp" | "logo" | "lua" | "marko" | "matlab" | "mdc" | "mdx" | "mermaid" | "mojo" | "nginx" | "nim" | "nix" | "objective-cpp" | "ocaml" | "pascal" | "perl" | "php" | "plsql" | "postcss" | "powerquery" | "prisma" | "prolog" | "proto" | "puppet" | "purescript" | "r" | "razor" | "reg" | "rel" | "riscv" | "rst" | "sas" | "sass" | "scala" | "scheme" | "scss" | "smalltalk" | "solidity" | "sparql" | "sql" | "ssh-config" | "stata" | "svelte" | "swift" | "system-verilog" | "tasl" | "tcl" | "tex" | "toml" | "tsx" | "turtle" | "twig" | "v" | "verilog" | "vhdl" | "vue" | "vue-html" | "wasm" | "wgsl" | "wolfram" | "xml" | "xsl" | "zenscript" | "zig", "css-variables" | "dark-plus" | "dracula" | "dracula-soft" | "github-dark" | "github-dark-dimmed" | "github-light" | "hc_light" | "light-plus" | "material-theme" | "material-theme-darker" | "material-theme-lighter" | "material-theme-ocean" | "material-theme-palenight" | "min-dark" | "min-light" | "monokai" | "nord" | "one-dark-pro" | "poimandres" | "rose-pine" | "rose-pine-dawn" | "rose-pine-moon" | "slack-dark" | "slack-ochin" | "solarized-dark" | "solarized-light" | "vitesse-dark" | "vitesse-light">;
declare const codeToHtml: (code: string, options: CodeToHastOptions<"shellscript" | "bat" | "berry" | "csharp" | "cpp" | "cadence" | "clojure" | "vb" | "shellsession" | "cypher" | "docker" | "erlang" | "fsharp" | "jssm" | "glimmer-js" | "graphql" | "glimmer-ts" | "handlebars" | "haskell" | "pug" | "javascript" | "kusto" | "kotlin" | "make" | "markdown" | "narrat" | "nextflow" | "objective-c" | "raku" | "ini" | "powershell" | "python" | "codeql" | "ruby" | "rust" | "shaderlab" | "splunk" | "stylus" | "typescript" | "viml" | "vyper" | "yaml" | "wenyan" | "bash" | "batch" | "be" | "c#" | "c++" | "cdc" | "clj" | "cmd" | "console" | "cql" | "cs" | "dockerfile" | "erl" | "f#" | "fs" | "fsl" | "gjs" | "gql" | "gts" | "hbs" | "hs" | "jade" | "js" | "kql" | "kt" | "kts" | "makefile" | "md" | "nar" | "nf" | "objc" | "perl6" | "properties" | "ps" | "ps1" | "py" | "ql" | "rb" | "rs" | "sh" | "shader" | "shell" | "spl" | "styl" | "ts" | "vim" | "vimscript" | "vy" | "yml" | "zsh" | "文言" | "abap" | "actionscript-3" | "ada" | "apache" | "apex" | "apl" | "applescript" | "ara" | "asm" | "astro" | "awk" | "ballerina" | "beancount" | "bibtex" | "bicep" | "blade" | "c" | "clarity" | "cmake" | "cobol" | "coffee" | "crystal" | "css" | "cue" | "d" | "dart" | "dax" | "diff" | "dream-maker" | "elixir" | "elm" | "erb" | "fish" | "gdresource" | "gdscript" | "gdshader" | "gherkin" | "git-commit" | "git-rebase" | "glsl" | "gnuplot" | "go" | "groovy" | "hack" | "haml" | "hcl" | "hjson" | "hlsl" | "html" | "http" | "imba" | "java" | "jinja-html" | "jison" | "json" | "json5" | "jsonc" | "jsonl" | "jsonnet" | "jsx" | "julia" | "latex" | "less" | "liquid" | "lisp" | "logo" | "lua" | "marko" | "matlab" | "mdc" | "mdx" | "mermaid" | "mojo" | "nginx" | "nim" | "nix" | "objective-cpp" | "ocaml" | "pascal" | "perl" | "php" | "plsql" | "postcss" | "powerquery" | "prisma" | "prolog" | "proto" | "puppet" | "purescript" | "r" | "razor" | "reg" | "rel" | "riscv" | "rst" | "sas" | "sass" | "scala" | "scheme" | "scss" | "smalltalk" | "solidity" | "sparql" | "sql" | "ssh-config" | "stata" | "svelte" | "swift" | "system-verilog" | "tasl" | "tcl" | "tex" | "toml" | "tsx" | "turtle" | "twig" | "v" | "verilog" | "vhdl" | "vue" | "vue-html" | "wasm" | "wgsl" | "wolfram" | "xml" | "xsl" | "zenscript" | "zig", "css-variables" | "dark-plus" | "dracula" | "dracula-soft" | "github-dark" | "github-dark-dimmed" | "github-light" | "hc_light" | "light-plus" | "material-theme" | "material-theme-darker" | "material-theme-lighter" | "material-theme-ocean" | "material-theme-palenight" | "min-dark" | "min-light" | "monokai" | "nord" | "one-dark-pro" | "poimandres" | "rose-pine" | "rose-pine-dawn" | "rose-pine-moon" | "slack-dark" | "slack-ochin" | "solarized-dark" | "solarized-light" | "vitesse-dark" | "vitesse-light">) => Promise<string>;
declare const codeToHast: (code: string, options: CodeToHastOptions<"shellscript" | "bat" | "berry" | "csharp" | "cpp" | "cadence" | "clojure" | "vb" | "shellsession" | "cypher" | "docker" | "erlang" | "fsharp" | "jssm" | "glimmer-js" | "graphql" | "glimmer-ts" | "handlebars" | "haskell" | "pug" | "javascript" | "kusto" | "kotlin" | "make" | "markdown" | "narrat" | "nextflow" | "objective-c" | "raku" | "ini" | "powershell" | "python" | "codeql" | "ruby" | "rust" | "shaderlab" | "splunk" | "stylus" | "typescript" | "viml" | "vyper" | "yaml" | "wenyan" | "bash" | "batch" | "be" | "c#" | "c++" | "cdc" | "clj" | "cmd" | "console" | "cql" | "cs" | "dockerfile" | "erl" | "f#" | "fs" | "fsl" | "gjs" | "gql" | "gts" | "hbs" | "hs" | "jade" | "js" | "kql" | "kt" | "kts" | "makefile" | "md" | "nar" | "nf" | "objc" | "perl6" | "properties" | "ps" | "ps1" | "py" | "ql" | "rb" | "rs" | "sh" | "shader" | "shell" | "spl" | "styl" | "ts" | "vim" | "vimscript" | "vy" | "yml" | "zsh" | "文言" | "abap" | "actionscript-3" | "ada" | "apache" | "apex" | "apl" | "applescript" | "ara" | "asm" | "astro" | "awk" | "ballerina" | "beancount" | "bibtex" | "bicep" | "blade" | "c" | "clarity" | "cmake" | "cobol" | "coffee" | "crystal" | "css" | "cue" | "d" | "dart" | "dax" | "diff" | "dream-maker" | "elixir" | "elm" | "erb" | "fish" | "gdresource" | "gdscript" | "gdshader" | "gherkin" | "git-commit" | "git-rebase" | "glsl" | "gnuplot" | "go" | "groovy" | "hack" | "haml" | "hcl" | "hjson" | "hlsl" | "html" | "http" | "imba" | "java" | "jinja-html" | "jison" | "json" | "json5" | "jsonc" | "jsonl" | "jsonnet" | "jsx" | "julia" | "latex" | "less" | "liquid" | "lisp" | "logo" | "lua" | "marko" | "matlab" | "mdc" | "mdx" | "mermaid" | "mojo" | "nginx" | "nim" | "nix" | "objective-cpp" | "ocaml" | "pascal" | "perl" | "php" | "plsql" | "postcss" | "powerquery" | "prisma" | "prolog" | "proto" | "puppet" | "purescript" | "r" | "razor" | "reg" | "rel" | "riscv" | "rst" | "sas" | "sass" | "scala" | "scheme" | "scss" | "smalltalk" | "solidity" | "sparql" | "sql" | "ssh-config" | "stata" | "svelte" | "swift" | "system-verilog" | "tasl" | "tcl" | "tex" | "toml" | "tsx" | "turtle" | "twig" | "v" | "verilog" | "vhdl" | "vue" | "vue-html" | "wasm" | "wgsl" | "wolfram" | "xml" | "xsl" | "zenscript" | "zig", "css-variables" | "dark-plus" | "dracula" | "dracula-soft" | "github-dark" | "github-dark-dimmed" | "github-light" | "hc_light" | "light-plus" | "material-theme" | "material-theme-darker" | "material-theme-lighter" | "material-theme-ocean" | "material-theme-palenight" | "min-dark" | "min-light" | "monokai" | "nord" | "one-dark-pro" | "poimandres" | "rose-pine" | "rose-pine-dawn" | "rose-pine-moon" | "slack-dark" | "slack-ochin" | "solarized-dark" | "solarized-light" | "vitesse-dark" | "vitesse-light">) => Promise<Root>;
declare const codeToThemedTokens: (code: string, options: RequireKeys<CodeToThemedTokensOptions<"shellscript" | "bat" | "berry" | "csharp" | "cpp" | "cadence" | "clojure" | "vb" | "shellsession" | "cypher" | "docker" | "erlang" | "fsharp" | "jssm" | "glimmer-js" | "graphql" | "glimmer-ts" | "handlebars" | "haskell" | "pug" | "javascript" | "kusto" | "kotlin" | "make" | "markdown" | "narrat" | "nextflow" | "objective-c" | "raku" | "ini" | "powershell" | "python" | "codeql" | "ruby" | "rust" | "shaderlab" | "splunk" | "stylus" | "typescript" | "viml" | "vyper" | "yaml" | "wenyan" | "bash" | "batch" | "be" | "c#" | "c++" | "cdc" | "clj" | "cmd" | "console" | "cql" | "cs" | "dockerfile" | "erl" | "f#" | "fs" | "fsl" | "gjs" | "gql" | "gts" | "hbs" | "hs" | "jade" | "js" | "kql" | "kt" | "kts" | "makefile" | "md" | "nar" | "nf" | "objc" | "perl6" | "properties" | "ps" | "ps1" | "py" | "ql" | "rb" | "rs" | "sh" | "shader" | "shell" | "spl" | "styl" | "ts" | "vim" | "vimscript" | "vy" | "yml" | "zsh" | "文言" | "abap" | "actionscript-3" | "ada" | "apache" | "apex" | "apl" | "applescript" | "ara" | "asm" | "astro" | "awk" | "ballerina" | "beancount" | "bibtex" | "bicep" | "blade" | "c" | "clarity" | "cmake" | "cobol" | "coffee" | "crystal" | "css" | "cue" | "d" | "dart" | "dax" | "diff" | "dream-maker" | "elixir" | "elm" | "erb" | "fish" | "gdresource" | "gdscript" | "gdshader" | "gherkin" | "git-commit" | "git-rebase" | "glsl" | "gnuplot" | "go" | "groovy" | "hack" | "haml" | "hcl" | "hjson" | "hlsl" | "html" | "http" | "imba" | "java" | "jinja-html" | "jison" | "json" | "json5" | "jsonc" | "jsonl" | "jsonnet" | "jsx" | "julia" | "latex" | "less" | "liquid" | "lisp" | "logo" | "lua" | "marko" | "matlab" | "mdc" | "mdx" | "mermaid" | "mojo" | "nginx" | "nim" | "nix" | "objective-cpp" | "ocaml" | "pascal" | "perl" | "php" | "plsql" | "postcss" | "powerquery" | "prisma" | "prolog" | "proto" | "puppet" | "purescript" | "r" | "razor" | "reg" | "rel" | "riscv" | "rst" | "sas" | "sass" | "scala" | "scheme" | "scss" | "smalltalk" | "solidity" | "sparql" | "sql" | "ssh-config" | "stata" | "svelte" | "swift" | "system-verilog" | "tasl" | "tcl" | "tex" | "toml" | "tsx" | "turtle" | "twig" | "v" | "verilog" | "vhdl" | "vue" | "vue-html" | "wasm" | "wgsl" | "wolfram" | "xml" | "xsl" | "zenscript" | "zig", "css-variables" | "dark-plus" | "dracula" | "dracula-soft" | "github-dark" | "github-dark-dimmed" | "github-light" | "hc_light" | "light-plus" | "material-theme" | "material-theme-darker" | "material-theme-lighter" | "material-theme-ocean" | "material-theme-palenight" | "min-dark" | "min-light" | "monokai" | "nord" | "one-dark-pro" | "poimandres" | "rose-pine" | "rose-pine-dawn" | "rose-pine-moon" | "slack-dark" | "slack-ochin" | "solarized-dark" | "solarized-light" | "vitesse-dark" | "vitesse-light">, "lang" | "theme">) => Promise<ThemedToken[][]>;
declare const codeToTokensWithThemes: (code: string, options: RequireKeys<CodeToTokensWithThemesOptions<"shellscript" | "bat" | "berry" | "csharp" | "cpp" | "cadence" | "clojure" | "vb" | "shellsession" | "cypher" | "docker" | "erlang" | "fsharp" | "jssm" | "glimmer-js" | "graphql" | "glimmer-ts" | "handlebars" | "haskell" | "pug" | "javascript" | "kusto" | "kotlin" | "make" | "markdown" | "narrat" | "nextflow" | "objective-c" | "raku" | "ini" | "powershell" | "python" | "codeql" | "ruby" | "rust" | "shaderlab" | "splunk" | "stylus" | "typescript" | "viml" | "vyper" | "yaml" | "wenyan" | "bash" | "batch" | "be" | "c#" | "c++" | "cdc" | "clj" | "cmd" | "console" | "cql" | "cs" | "dockerfile" | "erl" | "f#" | "fs" | "fsl" | "gjs" | "gql" | "gts" | "hbs" | "hs" | "jade" | "js" | "kql" | "kt" | "kts" | "makefile" | "md" | "nar" | "nf" | "objc" | "perl6" | "properties" | "ps" | "ps1" | "py" | "ql" | "rb" | "rs" | "sh" | "shader" | "shell" | "spl" | "styl" | "ts" | "vim" | "vimscript" | "vy" | "yml" | "zsh" | "文言" | "abap" | "actionscript-3" | "ada" | "apache" | "apex" | "apl" | "applescript" | "ara" | "asm" | "astro" | "awk" | "ballerina" | "beancount" | "bibtex" | "bicep" | "blade" | "c" | "clarity" | "cmake" | "cobol" | "coffee" | "crystal" | "css" | "cue" | "d" | "dart" | "dax" | "diff" | "dream-maker" | "elixir" | "elm" | "erb" | "fish" | "gdresource" | "gdscript" | "gdshader" | "gherkin" | "git-commit" | "git-rebase" | "glsl" | "gnuplot" | "go" | "groovy" | "hack" | "haml" | "hcl" | "hjson" | "hlsl" | "html" | "http" | "imba" | "java" | "jinja-html" | "jison" | "json" | "json5" | "jsonc" | "jsonl" | "jsonnet" | "jsx" | "julia" | "latex" | "less" | "liquid" | "lisp" | "logo" | "lua" | "marko" | "matlab" | "mdc" | "mdx" | "mermaid" | "mojo" | "nginx" | "nim" | "nix" | "objective-cpp" | "ocaml" | "pascal" | "perl" | "php" | "plsql" | "postcss" | "powerquery" | "prisma" | "prolog" | "proto" | "puppet" | "purescript" | "r" | "razor" | "reg" | "rel" | "riscv" | "rst" | "sas" | "sass" | "scala" | "scheme" | "scss" | "smalltalk" | "solidity" | "sparql" | "sql" | "ssh-config" | "stata" | "svelte" | "swift" | "system-verilog" | "tasl" | "tcl" | "tex" | "toml" | "tsx" | "turtle" | "twig" | "v" | "verilog" | "vhdl" | "vue" | "vue-html" | "wasm" | "wgsl" | "wolfram" | "xml" | "xsl" | "zenscript" | "zig", "css-variables" | "dark-plus" | "dracula" | "dracula-soft" | "github-dark" | "github-dark-dimmed" | "github-light" | "hc_light" | "light-plus" | "material-theme" | "material-theme-darker" | "material-theme-lighter" | "material-theme-ocean" | "material-theme-palenight" | "min-dark" | "min-light" | "monokai" | "nord" | "one-dark-pro" | "poimandres" | "rose-pine" | "rose-pine-dawn" | "rose-pine-moon" | "slack-dark" | "slack-ochin" | "solarized-dark" | "solarized-light" | "vitesse-dark" | "vitesse-light">, "lang" | "themes">) => Promise<[color: string, theme: string, tokens: ThemedToken[][]][]>;
declare const getSingletonHighlighter: () => Promise<HighlighterGeneric<"shellscript" | "bat" | "berry" | "csharp" | "cpp" | "cadence" | "clojure" | "vb" | "shellsession" | "cypher" | "docker" | "erlang" | "fsharp" | "jssm" | "glimmer-js" | "graphql" | "glimmer-ts" | "handlebars" | "haskell" | "pug" | "javascript" | "kusto" | "kotlin" | "make" | "markdown" | "narrat" | "nextflow" | "objective-c" | "raku" | "ini" | "powershell" | "python" | "codeql" | "ruby" | "rust" | "shaderlab" | "splunk" | "stylus" | "typescript" | "viml" | "vyper" | "yaml" | "wenyan" | "bash" | "batch" | "be" | "c#" | "c++" | "cdc" | "clj" | "cmd" | "console" | "cql" | "cs" | "dockerfile" | "erl" | "f#" | "fs" | "fsl" | "gjs" | "gql" | "gts" | "hbs" | "hs" | "jade" | "js" | "kql" | "kt" | "kts" | "makefile" | "md" | "nar" | "nf" | "objc" | "perl6" | "properties" | "ps" | "ps1" | "py" | "ql" | "rb" | "rs" | "sh" | "shader" | "shell" | "spl" | "styl" | "ts" | "vim" | "vimscript" | "vy" | "yml" | "zsh" | "文言" | "abap" | "actionscript-3" | "ada" | "apache" | "apex" | "apl" | "applescript" | "ara" | "asm" | "astro" | "awk" | "ballerina" | "beancount" | "bibtex" | "bicep" | "blade" | "c" | "clarity" | "cmake" | "cobol" | "coffee" | "crystal" | "css" | "cue" | "d" | "dart" | "dax" | "diff" | "dream-maker" | "elixir" | "elm" | "erb" | "fish" | "gdresource" | "gdscript" | "gdshader" | "gherkin" | "git-commit" | "git-rebase" | "glsl" | "gnuplot" | "go" | "groovy" | "hack" | "haml" | "hcl" | "hjson" | "hlsl" | "html" | "http" | "imba" | "java" | "jinja-html" | "jison" | "json" | "json5" | "jsonc" | "jsonl" | "jsonnet" | "jsx" | "julia" | "latex" | "less" | "liquid" | "lisp" | "logo" | "lua" | "marko" | "matlab" | "mdc" | "mdx" | "mermaid" | "mojo" | "nginx" | "nim" | "nix" | "objective-cpp" | "ocaml" | "pascal" | "perl" | "php" | "plsql" | "postcss" | "powerquery" | "prisma" | "prolog" | "proto" | "puppet" | "purescript" | "r" | "razor" | "reg" | "rel" | "riscv" | "rst" | "sas" | "sass" | "scala" | "scheme" | "scss" | "smalltalk" | "solidity" | "sparql" | "sql" | "ssh-config" | "stata" | "svelte" | "swift" | "system-verilog" | "tasl" | "tcl" | "tex" | "toml" | "tsx" | "turtle" | "twig" | "v" | "verilog" | "vhdl" | "vue" | "vue-html" | "wasm" | "wgsl" | "wolfram" | "xml" | "xsl" | "zenscript" | "zig", "css-variables" | "dark-plus" | "dracula" | "dracula-soft" | "github-dark" | "github-dark-dimmed" | "github-light" | "hc_light" | "light-plus" | "material-theme" | "material-theme-darker" | "material-theme-lighter" | "material-theme-ocean" | "material-theme-palenight" | "min-dark" | "min-light" | "monokai" | "nord" | "one-dark-pro" | "poimandres" | "rose-pine" | "rose-pine-dawn" | "rose-pine-moon" | "slack-dark" | "slack-ochin" | "solarized-dark" | "solarized-light" | "vitesse-dark" | "vitesse-light">>;

export { BuiltinLanguage, BuiltinTheme, CodeToHastOptions, CodeToThemedTokensOptions, CodeToTokensWithThemesOptions, GetHighlighterFactory, type Highlighter, HighlighterGeneric, RequireKeys, ThemedToken, codeToHast, codeToHtml, codeToThemedTokens, codeToTokensWithThemes, getHighlighter, getSingletonHighlighter };
